==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/gautoccdetails_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists gautoccdetails_au//
create trigger gautoccdetails_au after update on gautoccdetails
  for each row 
begin
  insert into changeprot
    (groupID, accessID, changedtable, tableID, userID, username, action,
     domain, server, section, teststep, newvalues)
  select NEW.groupID, NEW.accessID, 'gautoccdetails', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    showreg(NEW.domain, NEW.domain_v), showreg(NEW.server, NEW.server_v),
    showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
    concat('detail=', teststepdetails.name, '\nunit=', einheiten.name,
           '\nexpression=', NEW.formel, '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'),
           '\nactive=', NEW.aktiv)
  from teststepdetails, einheiten
  where NEW.TS != OLD.TS and teststepdetails.ID = NEW.teststepdetailsID and einheiten.ID = einheitID;
end//


drop trigger if exists gautoccdetails_ai//
create trigger gautoccdetails_ai after insert on gautoccdetails
  for each row 
begin
  insert into changeprot
    (groupID, accessID, changedtable, tableID, userID, username, action,
     domain, server, section, teststep, newvalues)
  select NEW.groupID, NEW.accessID, 'gautoccdetails', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    showreg(NEW.domain, NEW.domain_v), showreg(NEW.server, NEW.server_v),
    showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
    concat('detail=', teststepdetails.name, '\nunit=', einheiten.name,
           '\nexpression=', NEW.formel, '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'),
           '\nactive=', NEW.aktiv)
  from teststepdetails, einheiten
  where teststepdetails.ID = NEW.teststepdetailsID and einheiten.ID = einheitID;
end//


drop trigger if exists gautoccdetails_bd//
create trigger gautoccdetails_bd before delete on gautoccdetails
  for each row 
begin
  insert into changeprot
    (groupID, accessID, changedtable, tableID, userID, username, action,
     domain, server, section, teststep, newvalues)
  values
    (OLD.groupID, OLD.accessID, 'gautoccdetails', OLD.ID,
     coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
     showreg(OLD.domain, OLD.domain_v), showreg(OLD.server, OLD.server_v),
     showreg(OLD.section, OLD.section_v), showreg(OLD.teststep, OLD.teststep_v),
     coalesce(if(OLD.bemerkungen = @ccdetailsremark, '', concat('remark=', REPLACE(REPLACE(@ccdetailsremark, '\\', '\\\\'), '\n', '\\n'))),''));
end//

delimiter ;

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/gautoccdetails_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists gautoccdetails_au//
create trigger gautoccdetails_au after update on gautoccdetails
  for each row
begin
  insert into changeprot
    (groupID, accessID, changedtable, tableID, userID, username, action,
     domain, server, section, teststep, newvalues)
  select groupID, accessID, 'gautoccdetails', gautoccdetails.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    showreg(domain, domain_v), showreg(server, server_v),
    showreg(section, section_v), showreg(teststep, teststep_v),
    concat('detail=', teststepdetails.name, '\nunit=', einheiten.name,
           '\nexpression=', formel, '\nremark=', REPLACE(REPLACE(bemerkungen, '\\', '\\\\'), '\n', '\\n'),
           '\nactive=', aktiv)
  from gautoccdetails
  join teststepdetails on teststepdetails.ID = teststepdetailsID
  join einheiten on einheiten.ID = einheitID
  where gautoccdetails.ID = NEW.ID and gautoccdetails.TS = NEW.TS;
end//


drop trigger if exists gautoccdetails_ai//
create trigger gautoccdetails_ai after insert on gautoccdetails
  for each row
begin
  insert into changeprot
    (groupID, accessID, changedtable, tableID, userID, username, action,
     domain, server, section, teststep, newvalues)
  select NEW.groupID, NEW.accessID, 'gautoccdetails', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    showreg(NEW.domain, NEW.domain_v), showreg(NEW.server, NEW.server_v),
    showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
    concat('detail=', teststepdetails.name, '\nunit=', einheiten.name,
           '\nexpression=', NEW.formel, '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'),
           '\nactive=', NEW.aktiv)
  from teststepdetails
  join einheiten on einheiten.ID = einheitID
  where teststepdetails.ID = NEW.teststepdetailsID;
end//


drop trigger if exists gautoccdetails_bd//
create trigger gautoccdetails_bd before delete on gautoccdetails
  for each row
begin
  insert into changeprot
    (groupID, accessID, changedtable, tableID, userID, username, action,
     domain, server, section, teststep, newvalues)
  values
    (OLD.groupID, OLD.accessID, 'gautoccdetails', OLD.ID,
     coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
     showreg(OLD.domain, OLD.domain_v), showreg(OLD.server, OLD.server_v),
     showreg(OLD.section, OLD.section_v), showreg(OLD.teststep, OLD.teststep_v),
     coalesce(if(OLD.bemerkungen = @ccdetailsremark, '', concat('remark=', REPLACE(REPLACE(@ccdetailsremark, '\\', '\\\\'), '\n', '\\n'))),''));
end//

delimiter ;
